// BLEMInimalEdit2.ino

#include <ArduinoBLE.h> // rev 1.3.6

#define BLE_SERVICE_UUID "6b18ab86-7622-438c-a712-86a61eccbc7a"
#define BLE_CHARACTERISTIC_UUID "0a81e003-4280-4638-bf38-196f30f2a6df"

// Service
BLEService carService(BLE_SERVICE_UUID); 

//Characteristic
//BLEShortCharacteristic carControlCharacteristic(BLE_CHARACTERISTIC_UUID, BLEWrite | BLERead | BLENotify, 16); // compile error
BLEShortCharacteristic carControlCharacteristic(BLE_CHARACTERISTIC_UUID, BLEWrite | BLERead | BLENotify); // fixed

// -------------------------------------------------------------------------- 
void setup() 
{
  char msg[30] = "";

  // 1. Serial
  Serial.begin(115200);
  while(! Serial); 
  Serial.println();
  Serial.println("*** Start...");
  
  // 2. BLE
  if (!BLE.begin()) 
    {
      Serial.println("starting Bluetooth® Low Energy module failed!");
      while (1) 
      { // blink the built-in LED fast to indicate an issue
        digitalWrite(LED_BUILTIN, HIGH);
        delay(100);
        digitalWrite(LED_BUILTIN, LOW);
        delay(100);
      }
    }

  // Set up BLE
  BLE.setLocalName("UnoR4BLE");
  BLE.setAdvertisedService(carService);
  carService.addCharacteristic(carControlCharacteristic); // add the characteristics to the service
  BLE.addService(carService); // add the service
  carControlCharacteristic.writeValue(0);
  BLE.advertise(); // start advertising
  Serial.println("Bluetooth® Low Energy device active, waiting for connections...");

}

// -------------------------------------------------------------------------- 
void loop() 
{
  short AppCmd;

  BLEDevice controller = BLE.central(); // listen for BLE peripherals to connect:

  if (controller)  // if a central is connected to peripheral:
  {
    Serial.print("Connected to controller: ");
    Serial.println(controller.address()); // print the controller's MAC address:    
    digitalWrite(LED_BUILTIN, HIGH);  // when the central connects, turn on the LED
    
    // while the controller is still connected to peripheral:
    while (controller.connected()) 
    {
      if (carControlCharacteristic.written()) 
      {
        //carControlCharacteristic.readValue(AppCmd, 16); // compile error
        carControlCharacteristic.readValue(AppCmd); // fixed
        if(AppCmd > 0)
        {
          Serial.println("characteristic written");
          
          //switch (carControlCharacteristic.value()) 
          switch (AppCmd) 
          {
            case 1:
              Serial.println("LEFT");            
              break;
            case 2:
              Serial.println("RIGHT");            
              break;
            
            default:  // 0 or invalid control
              Serial.println("STOP");            
              break;
          }
        }
      }  
    }

    // when the central disconnects, print it out:
    Serial.print(F("Disconnected from controller: "));
    Serial.println(controller.address());
    digitalWrite(LED_BUILTIN, LOW);         // when the central disconnects, turn off the LED  

  }
}
